"use strict";
var i18n = function() {
	var defaultLoc = {
		locale : 'en',
		lang : 'en'
	};
	var localization = $.extend({}, defaultLoc, true);
	var mappings = {
		locale : {
			// default
			"en" : {
				centerCoords : {
					center : [ 47.848816, 15.856126 ],
					zoom : 3
				},
				metric : 'SI'
			},
			"PL" : {
				centerCoords : {
					center : [ 52, 20 ],
					zoom : 5
				},
				metric : 'SI'
			},
			"US" : {
				centerCoords : {
					center : [ 39.50, -98.35 ],
					zoom : 3
				},
				metric : 'IMPERIAL'
			},
			"IN" : {
				centerCoords : {
					center : [ 28.36, 77.12 ],
					zoom : 3
				},
				metric : 'SI'
			},
			"CH" : {
				centerCoords : {
					center : [ 46.57, 7.27 ],
					zoom : 6
				},
				metric : 'SI'
			},
			"IT" : {
				centerCoords : {
					center : [ 41.54, 12.29 ],
					zoom : 5
				},
				metric : 'SI'
			},
			"GB" : {
				centerCoords : {
					center : [ 51.30, 0.7 ],
					zoom : 5
				},
				metric : 'IMPERIAL'
			},
			"KR" : {
				centerCoords : {
					center : [ 37.33, 126.58 ],
					zoom : 5
				},
				metric : 'SI'
			},
			"CA" : {
				centerCoords : {
					center : [ 39.50, -98.35 ],
					zoom : 3
				},
				metric : 'IMPERIAL'
			},
			"AU" : {
				centerCoords : {
					center : [ -30, 140 ],
					zoom : 3
				},
				metric : 'IMPERIAL'
			},
			"NZ" : {
				centerCoords : {
					center : [ -30, 140 ],
					zoom : 3
				},
				metric : 'IMPERIAL'
			}
		},
		lang : {
			// default
			"en" : {},
			"pl" : {},
			"es" : {},
			"de" : {},
			"ko" : {},
			"ru" : {},
			"fr" : {},
			'fi' : {},
			'pt' : {}
		}
	};
	return {
		localizationInit : function(callback) {
			var err = "Unable to get device locale";
			if (navigator.globalization) {
				navigator.globalization.getLocaleName(function(lang) {
					if (!lang || !lang.value) {
						callback();
						return false;
					}
					try {
						var locale = lang.value.split("-");
						if (locale[0]) {
							localization.lang = (config.forceLanguage) ? config.forceLanguage : locale[0];
						}
						if (locale[1]) {
							localization.locale = locale[1];
						}
					} catch (e) {
					}
					callback();
				}, function() {
					console.error(err);
					callback();
				});
			} else if (navigator && navigator.language) {
				try {
					var locale = navigator.language.split("-");
					if (locale[0]) {
						localization.lang = (config.forceLanguage) ? config.forceLanguage : locale[0];
					}
					if (locale[1]) {
						localization.locale = (config.forceLocale) ? config.forceLocale : locale[1];
					}
				} catch (e) {
				}
				callback();
			} else {
				console.error(err);
				callback();
			}
		},
		getLocale : function() {
			var loc = defaultLoc;
			if (mappings.lang && mappings.lang[localization.lang])
				loc.lang = localization.lang;
			if (mappings.locale && mappings.locale[localization.locale])
				loc.locale = localization.locale;
			return loc;
		},
		getCountryCoords : function() {
			if (mappings.locale[localization.locale])
				return mappings.locale[localization.locale].centerCoords;
			else
				return mappings.locale["en"].centerCoords;
		},
		getMetricSystem : function() {
			if (mappings.locale[localization.locale])
				return mappings.locale[localization.locale].metric;
			else
				return mappings.locale["en"].metric;
		},
		unitTransformation : function(val) {
			/**
			 * If settings module available information about units is taken
			 * from there
			 */
			if (settings) {
				if (settings.get(settings.types.units) === "miles")
					return view.round(val / 1.609) + i18nLang.get("miles");
				else
					return view.round(val) + i18nLang.get("km");
				return false;
			}
			if (this.getMetricSystem() === "IMPERIAL")
				return view.round(val / 1.609) + i18nLang.get("miles");
			else
				return view.round(val) + i18nLang.get("km");
		},
		unitTransformationArea : function(val) {
			/**
			 * If settings module available information about units is taken
			 * from there
			 */
			if (settings) {
				if (settings.get(settings.types.units) === "miles")
					return view.round(val * 0.3861022) + i18nLang.get("sqMiles");
				else
					return view.round(val) + 'km<sup>2</sup>';
			}

			if (this.getMetricSystem() === "IMPERIAL")
				return view.round(val * 0.3861022) + i18nLang.get("sqMiles");
			else
				return view.round(val) + 'km<sup>2</sup>';
		},
		unitTransformationMeters : function(val) {
			/**
			 * If settings module available information about units is taken
			 * from there
			 */
			if (settings) {
				if (settings.get(settings.types.units) === "miles")
					return view.round(val / 0.9144) + i18nLang.get("yards");
				else
					return view.round(val) + i18nLang.get("meters");
			}
			if (this.getMetricSystem() === "IMPERIAL")
				return view.round(val / 0.9144) + i18nLang.get("yards");
			else
				return view.round(val) + i18nLang.get("meters");
		}
	}
}();